/* PhyloPattern
 * Copyright (C) 2005-2009 Philippe Gouret
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA. The text ol license can be also found 
 * at http://www.gnu.org/copyleft/gpl.html
 */

//------------------------------------------------------------------------------
// get bootstrap value list from label
//Philippe Gouret
//------------------------------------------------------------------------------

//prolog buildins package
package gnu.prolog.vm.buildins.PhyloPattern;

//import classes
import gnu.prolog.term.*;
import gnu.prolog.vm.*;
import gnu.prolog.io.*;
import java.io.*;
import java.util.*;

//project classes


/** prolog code
 */
public class Predicate_bootstrap_label implements PrologCode, TermConstants
{
	/** this method is used for execution of code
	 * @param interpreter interpreter in which context code is executed
	 * @param backtrackMode true if predicate is called on backtracking and false otherwise
	 * @param args arguments of code
	 * @return either SUCCESS, SUCCESS_LAST, or FAIL.
	 */
	public int execute(Interpreter interpreter, boolean backtrackMode, gnu.prolog.term.Term args[])
	throws PrologException
	{
		// get parameters
		Term inTerm = args[0];
		Term outTerm = args[1];

		// atom to convert
		if (!(inTerm instanceof AtomTerm)) PrologException.typeError(atomAtom, inTerm);
		String bootstrap = ((AtomTerm) inTerm).value;

		// out
		if (!(outTerm instanceof VariableTerm)) PrologException.typeError(variableAtom, outTerm);
		VariableTerm out = (VariableTerm) outTerm;

		try
		{
			// parse
			List<IntegerTerm> bootstrapsList = new Vector<IntegerTerm>();
			StringTokenizer parser = new StringTokenizer(bootstrap, "_*");
			while (parser.hasMoreTokens())
			{
				String one = parser.nextToken();
				bootstrapsList.add(IntegerTerm.get(Integer.parseInt(one)));
			}
			
			// transform in term
			interpreter.addVariableUndo(out);
			out.value = CompoundTerm.getList(bootstrapsList);

			// success
			return SUCCESS_LAST;
		}
		catch (Exception e)
		{
			// error
			return FAIL;
		}
	}

	/** this method is called when code is installed to the environment
	 * code can be installed only for one environment.
	 * @param environment environemnt to install the predicate
	 */
	public void install(Environment env)
	{

	}

	/** this method is called when code is uninstalled from the environment
	 * @param environment environemnt to install the predicate
	 */
	public void uninstall(Environment env)
	{
	}

}

